import React, { useEffect, useState, useMemo } from "react";
import { FollowerNode, ChannelEvents, } from "@local-logic/channel";
import { useSearch, useNavigate, useLocation, } from "@tanstack/react-location";
import once from "lodash.once";
import { primitiveUtils } from "@local-logic/core/utils";
import useEffectOnce from "~/hooks/useEffectOnce";
import useDebounce from "~/hooks/useDebounce";
import errorTracker from "~/utils/errorTracker";
import defaultState from "./defaultState";
import i18n from "../../i18n";
// Using once to get around generic Context issue: https://stackoverflow.com/a/61020816/4282290
const createStateManagerContext = once(() => React.createContext({}));
const useStateManagerContext = () => {
    const context = React.useContext(createStateManagerContext());
    if (!context) {
        throw new Error("useStateManagerContext must be used under StateManagerProvider");
    }
    return context;
};
const StateManagerProvider = React.memo(({ children }) => {
    var _a;
    const StateManagerContext = createStateManagerContext();
    const search = useSearch();
    const sdkStateRef = React.useRef(search);
    const location = useLocation();
    const pathSegments = location.current.pathname.split("/");
    const currentRoute = pathSegments[pathSegments.length - 1];
    const defaultSDKState = defaultState[currentRoute];
    const followerNodeRef = React.useRef();
    const [isConnected, setIsConnected] = useState(false);
    const [sdkState, _setSdkState] = useState(defaultSDKState);
    const debouncedSdkState = useDebounce(sdkState, 500);
    const navigate = useNavigate();
    const setSdkState = (data) => {
        sdkStateRef.current = data;
        _setSdkState(data);
    };
    const handleMessage = (e) => {
        var _a;
        if (e.name === ChannelEvents.GET_STATE) {
            (_a = followerNodeRef.current) === null || _a === void 0 ? void 0 : _a.message(ChannelEvents.GET_STATE_RESPONSE, sdkStateRef.current, e.eventId);
        }
        if (e.name === ChannelEvents.SET_STATE) {
            setSdkState(e.data);
        }
    };
    /**
     * The `.connect()` event should only every be triggered once.
     */
    useEffectOnce(() => {
        const followerNode = new FollowerNode(search.channelId, {
            targetOrigin: document.referrer,
            window: window.parent,
        });
        followerNodeRef.current = followerNode;
        followerNode === null || followerNode === void 0 ? void 0 : followerNode.onMessage(handleMessage);
        followerNode === null || followerNode === void 0 ? void 0 : followerNode.connect().then((resp) => {
            const mergedState = primitiveUtils.object.mergeDeep(sdkState, resp.data);
            setSdkState(mergedState);
            setIsConnected(true);
            errorTracker.addBreadCrumb("stateManager", "useEffectOnce: Connected to sdks-js", {
                oldState: sdkState,
                newState: resp.data,
                mergedState,
            });
        });
    });
    const onChange = (e) => {
        var _a;
        (_a = followerNodeRef.current) === null || _a === void 0 ? void 0 : _a.message(ChannelEvents.ON_CHANGE, e);
        errorTracker.addBreadCrumb("stateManager", "onChange", {
            data: e,
        });
    };
    useEffect(() => {
        navigate({
            search: () => debouncedSdkState,
            replace: true,
        });
    }, [debouncedSdkState]);
    useEffect(() => {
        if (sdkState.options) {
            onChange({ type: "options", data: sdkState.options });
        }
    }, [sdkState.options]);
    const contextValue = useMemo(() => ({
        sdkState,
        setSdkState,
        onChange,
        followerNode: followerNodeRef.current,
    }), [sdkState, setSdkState, onChange]);
    useEffect(() => {
        var _a, _b;
        // Avoids unecessarily setting the language multiple times
        if (!isConnected || !((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale)) {
            return;
        }
        const language = ((_b = sdkState.globalOptions) === null || _b === void 0 ? void 0 : _b.locale) || "en";
        if (i18n.language !== language) {
            errorTracker.addBreadCrumb("stateManager", "i18n.changeLanguage", {
                language,
            });
            i18n.changeLanguage(language);
        }
    }, [(_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale, isConnected]);
    if (!isConnected) {
        return null;
    }
    return (React.createElement(StateManagerContext.Provider, { value: contextValue }, children));
});
StateManagerProvider.displayName = "StateManagerProvider";
export { useStateManagerContext, StateManagerProvider };
//# sourceMappingURL=index.js.map