import React from "react";
import { render, screen } from "@testing-library/react";
import { describe, it, vi, beforeEach } from "vitest";
import { useOnEventOutside } from "~/hooks/useOnEventOutside";
import { Content } from "./index";
// Mock context
const mockOnToggleIsExpanded = vi.fn();
const mockUseRootElement = vi.fn();
vi.mock("../context", () => ({
    useRootElement: () => mockUseRootElement(),
}));
// Mock useOnEventOutside
vi.mock("~/hooks/useOnEventOutside", () => ({
    useOnEventOutside: vi.fn(),
}));
describe("Content", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("should not render when isExpanded is false", () => {
        mockUseRootElement.mockReturnValue({
            activeCategory: null,
            isExpanded: false,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        const { container } = render(React.createElement(Content, null, "Children"));
        expect(container.firstChild).toBeNull();
    });
    it("should render children when isExpanded is true", () => {
        mockUseRootElement.mockReturnValue({
            activeCategory: null,
            isExpanded: true,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        render(React.createElement(Content, null, "Test Child"));
        expect(screen.getByTestId("categories-panel")).toBeInTheDocument();
        expect(screen.getByText("Test Child")).toBeInTheDocument();
    });
    it("should set data attributes correctly", () => {
        mockUseRootElement.mockReturnValue({
            activeCategory: "cat1",
            isExpanded: true,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        render(React.createElement(Content, null));
        const panel = screen.getByTestId("categories-panel");
        expect(panel).toHaveAttribute("data-is-expanded", "true");
        expect(panel).toHaveAttribute("data-is-slider-open", "true");
    });
    it("should call onToggleIsExpanded when clicking outside if canClose is true", () => {
        let outsideHandler;
        vi.mocked(useOnEventOutside).mockImplementation((_ref, _event, handler) => {
            outsideHandler = handler;
        });
        mockUseRootElement.mockReturnValue({
            activeCategory: null,
            isExpanded: true,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        render(React.createElement(Content, null));
        // Simulate click outside
        if (typeof outsideHandler === "function") {
            outsideHandler();
        }
        expect(mockOnToggleIsExpanded).toHaveBeenCalled();
    });
    it("should not call onToggleIsExpanded when canClose is false", () => {
        let outsideHandler;
        vi.mocked(useOnEventOutside).mockImplementation((_ref, _event, handler) => {
            outsideHandler = handler;
        });
        // isExpanded false initially, so canClose is true, but after effect it becomes false
        mockUseRootElement.mockReturnValue({
            activeCategory: null,
            isExpanded: false,
            onToggleIsExpanded: mockOnToggleIsExpanded,
        });
        render(React.createElement(Content, null));
        // Simulate click outside
        if (typeof outsideHandler === "function") {
            outsideHandler();
        }
        expect(mockOnToggleIsExpanded).not.toHaveBeenCalled();
    });
});
//# sourceMappingURL=index.test.js.map