import { describe, it, expect, vi } from "vitest";
import { renderHook } from "@testing-library/react";
import { useMarkers } from "./index";
const usePoisMock = vi.fn(() => ({
    isLoading: false,
    data: {},
}));
vi.mock("~/features/clientLibrary/usePois", () => ({
    usePois: () => usePoisMock(),
}));
const useSchoolsMock = vi.fn(() => ({
    isLoading: false,
    data: {},
}));
vi.mock("~/features/clientLibrary/useSchools", () => ({
    useSchools: () => useSchoolsMock(),
}));
describe("useMarkers", () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it("should return loading state and data", () => {
        const { result } = renderHook(() => useMarkers({ lat: 0, lng: 0 }));
        expect(result.current.isLoading).toBe(false);
        expect(result.current.data).toEqual({});
    });
    it("should return pois data", () => {
        usePoisMock.mockReturnValueOnce({
            isLoading: false,
            data: {
                parks: [
                    {
                        name: "Test Park",
                        address: "address",
                        city: "city",
                        province: "province",
                        postalcode: "postalcode",
                        country: "country",
                        lat: 0,
                        lng: 0,
                        proximity: {
                            linear_distance: 0,
                            walking: undefined,
                        },
                    },
                ],
            },
        });
        const { result } = renderHook(() => useMarkers({ lat: 10, lng: 20, category: "parks" }));
        expect(result.current.data).toEqual({
            parks: [
                {
                    name: "Test Park",
                    address: "address",
                    city: "city",
                    province: "province",
                    postalcode: "postalcode",
                    country: "country",
                    lat: 0,
                    lng: 0,
                    proximity: {
                        linear_distance: 0,
                        walking: undefined,
                    },
                },
            ],
        });
    });
    it("should return schools data", () => {
        useSchoolsMock.mockReturnValueOnce({
            isLoading: false,
            data: {
                primary_schools: [
                    {
                        name: "Test School",
                        address: "address",
                        city: "city",
                        province: "province",
                        postalcode: "postalcode",
                        country: "country",
                        lat: 0,
                        lng: 0,
                        proximity: {
                            linear_distance: 0,
                            walking: undefined,
                        },
                    },
                ],
            },
        });
        const { result } = renderHook(() => useMarkers({ lat: 10, lng: 20, category: "primary_schools" }));
        expect(result.current.data).toEqual({
            primary_schools: [
                {
                    name: "Test School",
                    address: "address",
                    city: "city",
                    province: "province",
                    postalcode: "postalcode",
                    country: "country",
                    lat: 0,
                    lng: 0,
                    proximity: {
                        linear_distance: 0,
                        walking: undefined,
                    },
                },
            ],
        });
    });
    it("should handle loading state for pois and schools", () => {
        usePoisMock.mockReturnValueOnce({
            isLoading: true,
            data: {},
        });
        useSchoolsMock.mockReturnValueOnce({
            isLoading: false,
            data: {},
        });
        const { result } = renderHook(() => useMarkers({ lat: 10, lng: 20, category: "parks" }));
        expect(result.current.isLoading).toBe(true);
        expect(result.current.data).toEqual({});
    });
    it("should return empty data when no category is provided", () => {
        const { result } = renderHook(() => useMarkers({ lat: 10, lng: 20 }));
        expect(result.current.data).toEqual({});
    });
    it("should return empty data when category is not in categories", () => {
        const { result } = renderHook(() => 
        // @ts-expect-error Testing with a non-existent category
        useMarkers({ lat: 10, lng: 20, category: "non_existent_category" }));
        expect(result.current.data).toEqual({});
    });
});
//# sourceMappingURL=index.test.js.map