import { Input } from "@local-logic/core/ui";
import React, { useState, useEffect, useContext, useRef } from "react";
import { useStateManagerContext } from "~/context/stateManager";
import useDebounce from "~/hooks/useDebounce";
import { useLocalContent } from "~/sdks/LocalContentDeprecated/context";
import errorTracker from "~/utils/errorTracker";
import { GoogleMapContext } from "../../../../../Map/GoogleMap/context";
import Search from "../Search";
const SEARCH_RADIUS_METERS = 2000;
const SEARCH_COUNTRY_RESTRICTIONS = ["us", "ca"];
const GoogleSearch = ({ label, onSearch, onSelect, placeholder, renderListAbove = true, }) => {
    const { isInputAutoFocused } = useLocalContent();
    const { sdkState } = useStateManagerContext();
    const { googleMapRef } = useContext(GoogleMapContext);
    const [query, setQuery] = useState("");
    const debouncedQuery = useDebounce(query, 500);
    const [showResults, setShowResults] = useState(false);
    const [suggestionResults, setSuggestionResults] = useState([]);
    // A Google session token is required for billing optimization, aka to save money.
    // A session is defined as one or more place autocomplete searches followed by one place details request.
    // Full details at the following link:
    // https://developers.google.com/maps/documentation/javascript/place-autocomplete#session_tokens
    // useRef chosen to hold the same token between the services, unaffected by re-renders
    const sessionToken = useRef(null);
    useEffect(() => {
        var _a, _b;
        if (!sessionToken.current) {
            errorTracker.addBreadCrumb("GoogleSearch", "useEffect: Getting autocomplete session token");
            sessionToken.current = new google.maps.places.AutocompleteSessionToken();
        }
        const autocompleteService = new google.maps.places.AutocompleteService();
        const lat = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.lat;
        const lng = (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lng;
        if (!debouncedQuery || !lat || !lng) {
            return;
        }
        errorTracker.addBreadCrumb("GoogleSearch", "useEffect: Getting place predictions");
        autocompleteService.getPlacePredictions({
            input: debouncedQuery,
            locationBias: new google.maps.Circle({
                radius: SEARCH_RADIUS_METERS,
                center: { lat, lng },
            }),
            sessionToken: sessionToken.current,
            componentRestrictions: {
                country: SEARCH_COUNTRY_RESTRICTIONS,
            },
        }, (places, status) => {
            if (status !== google.maps.places.PlacesServiceStatus.OK || !places) {
                return;
            }
            const formattedPlaces = places.map((place) => ({
                locationId: place.place_id,
                address: { description: place.description },
            }));
            setSuggestionResults(formattedPlaces);
        });
    }, [debouncedQuery]);
    const getAndSetPlaceDetails = (map, placeId, description) => {
        errorTracker.addBreadCrumb("GoogleSearch", "getAndSetPlaceDetails", {
            placeId,
            description,
        });
        const placesService = new google.maps.places.PlacesService(map);
        // create a new session token if making another places getDetails call without Autocomplete.
        // This occurs when the user clicks on another search result without changing the original query.
        if (!sessionToken.current) {
            sessionToken.current = new google.maps.places.AutocompleteSessionToken();
        }
        placesService.getDetails({
            placeId,
            fields: ["geometry"],
            sessionToken: sessionToken.current,
        }, (place) => {
            var _a, _b, _c, _d;
            const latitude = (_b = (_a = place === null || place === void 0 ? void 0 : place.geometry) === null || _a === void 0 ? void 0 : _a.location) === null || _b === void 0 ? void 0 : _b.lat();
            const longitude = (_d = (_c = place === null || place === void 0 ? void 0 : place.geometry) === null || _c === void 0 ? void 0 : _c.location) === null || _d === void 0 ? void 0 : _d.lng();
            if (!latitude || !longitude) {
                return;
            }
            // Used up session token with a places getDetails call
            sessionToken.current = null;
            onSearch({
                address: description,
                latitude,
                longitude,
            });
            // remove query value to allow setDesttination
            // to do its job of changing the placeholder
            setQuery("");
        });
    };
    const handleItemClick = ({ locationId: lid, address, }) => {
        if (!lid || !address || !googleMapRef) {
            return;
        }
        getAndSetPlaceDetails(googleMapRef, lid, address.description);
    };
    return (React.createElement(Search, { onSelect: onSelect, renderListAbove: renderListAbove, query: query, showResults: showResults, suggestionResults: suggestionResults, onClick: handleItemClick },
        React.createElement(Input, { autofocus: isInputAutoFocused, value: query, label: label, placeholder: placeholder, onFocus: () => setShowResults(true), onBlur: () => setShowResults(false), onChange: (e) => {
                setQuery(e.currentTarget.value);
                setShowResults(true);
            } })));
};
export default GoogleSearch;
//# sourceMappingURL=index.js.map