import React, { useMemo, useState, useEffect } from "react";
import { useStateManagerContext } from "~/context/stateManager";
import { useFlags } from "launchdarkly-react-client-sdk";
import { useNeighborhoodMap } from "~/sdks/NeighborhoodMap/context";
import { useTracking } from "@local-logic/core/tracking";
import { mapUtils, typeguardUtils } from "@local-logic/core/utils";
import errorTracker from "~/utils/errorTracker";
import * as Map from "~/sdks/NeighborhoodMap/components/Map";
import { categories } from "~/sdks/NeighborhoodMap/constants";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/NeighborhoodMap/types";
import * as Filters from "../Filters";
import { RadiusDropdown } from "../RadiusDropdown";
import * as styles from "./styles";
export const Content = () => {
    var _a, _b;
    const { sdkState } = useStateManagerContext();
    const flags = useFlags();
    const tracking = useTracking();
    const [mapMarkers, setMapMarkers] = useState();
    const [schoolGeometry, setSchoolGeometry] = useState();
    const { isLoading, activePoiCategory, locationInfo, onSelectPoiCategory, neighborhoodGeometry, markers, } = useNeighborhoodMap();
    const [activeMarker, setActiveMarker] = useState(null);
    const [dialogSelectedPoiCategory, setDialogSelectedPoiCategory] = useState();
    useEffect(() => {
        if (isLoading) {
            return;
        }
        setMapMarkers(markers);
    }, [markers, isLoading]);
    useEffect(() => {
        if (activeMarker) {
            setActiveMarker(null);
        }
        setDialogSelectedPoiCategory(activePoiCategory);
    }, [activePoiCategory]);
    const poiCategories = useMemo(() => Object.entries(categories)
        .filter(([category]) => category !== "daycares" || flags.neighborhoodWrapDaycaresEnabled)
        .map(([category, value]) => ({
        key: category,
        icon: value.icon,
    })), [flags]);
    const mapBounds = useMemo(() => mapMarkers
        ? mapMarkers === null || mapMarkers === void 0 ? void 0 : mapMarkers.map((marker) => ({ lat: marker.lat, lng: marker.lng }))
        : undefined, [mapMarkers]);
    const handleOnSelectCategory = (category) => {
        onSelectPoiCategory(category);
        tracking.postEvent({
            eventType: TrackingPipelineEvents.CATEGORY_CLICKED,
            eventAttributes: [
                {
                    label: "category",
                    data: category,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.CATEGORY_CLICKED,
            eventAttributes: {
                ll_category: category,
            },
        });
    };
    const handleOnDialogSelectCategory = (category) => {
        setDialogSelectedPoiCategory(dialogSelectedPoiCategory === category ? undefined : category);
    };
    const handleMarkerClick = (marker) => () => {
        setActiveMarker(marker);
        errorTracker.addBreadCrumb("Content", "handleMarkerClick", {
            marker,
        });
        const activePoiType = "school_attributes" in marker ? "school" : "poi";
        if (typeguardUtils.poi.isSchool(marker, activePoiType) &&
            (marker === null || marker === void 0 ? void 0 : marker.catchments) &&
            Object.keys((marker === null || marker === void 0 ? void 0 : marker.catchments) || []).length > 0) {
            setSchoolGeometry(mapUtils.formatGeometry(marker.catchments[0].geometry));
        }
        else {
            setSchoolGeometry(undefined);
        }
        tracking.postEvent({
            eventType: TrackingPipelineEvents.POI_CLICKED,
            eventAttributes: [
                {
                    label: "category",
                    data: activePoiCategory,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.POI_CLICKED,
            eventAttributes: {
                ll_category: activePoiCategory,
            },
        });
    };
    const handleMarkerLinkClick = (url) => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.POI_LINK_CLICKED,
            eventAttributes: [
                {
                    label: "category",
                    data: activePoiCategory,
                },
                {
                    label: "clicked_url",
                    data: url,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.POI_LINK_CLICKED,
            eventAttributes: {
                ll_category: activePoiCategory,
                ll_clicked_url: url,
            },
        });
    };
    const handleMarkerPopupClose = () => {
        setActiveMarker(null);
        setSchoolGeometry(undefined);
    };
    const handleResetFilters = () => {
        onSelectPoiCategory(undefined);
    };
    const handleApplyFilter = () => {
        onSelectPoiCategory(dialogSelectedPoiCategory);
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(Filters.Root, null,
            React.createElement("div", { className: styles.header },
                React.createElement(Filters.ScrollList, null, poiCategories.map((poiCategory) => (React.createElement(Filters.Category, { key: `scroll-list-${poiCategory.key}`, category: poiCategory.key, icon: poiCategory.icon, activeCategory: activePoiCategory, onSelectCategory: handleOnSelectCategory })))),
                React.createElement(Filters.AllFiltersButton, null)),
            React.createElement(Filters.Dialog, { onReset: handleResetFilters, onApply: handleApplyFilter }, poiCategories.map((poiCategory) => (React.createElement(Filters.Category, { key: `dialog-scroll-list-${poiCategory.key}`, category: poiCategory.key, icon: poiCategory.icon, activeCategory: dialogSelectedPoiCategory, onSelectCategory: handleOnDialogSelectCategory })))),
            React.createElement(Map.Root, { options: Object.assign(Object.assign({}, sdkState.options), { lat: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates.lat, lng: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates.lng, theme: (_b = (_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.appearance) === null || _b === void 0 ? void 0 : _b.theme, geometries: [
                        {
                            key: "neighborhood",
                            geoJson: neighborhoodGeometry,
                            color: getComputedStyle(document.documentElement).getPropertyValue("--ll-color-primary"),
                        },
                        {
                            key: "school",
                            geoJson: schoolGeometry,
                            color: "#9333ea",
                        },
                    ] }) },
                React.createElement(Map.BaseMap, { bounds: mapBounds },
                    React.createElement(React.Fragment, null,
                        React.createElement("div", { className: styles.radiusSelector },
                            React.createElement(RadiusDropdown, null)), mapMarkers === null || mapMarkers === void 0 ? void 0 :
                        mapMarkers.map((marker, index) => (React.createElement(Map.Marker, { key: `poi-marker-${marker.address}-${index}`, lat: marker.lat, lng: marker.lng, icon: activePoiCategory && categories[activePoiCategory].icon, onClick: handleMarkerClick(marker) }))),
                        React.createElement(Map.Popup, { marker: activeMarker, icon: activePoiCategory && categories[activePoiCategory].icon, onClose: handleMarkerPopupClose, onLinkClick: handleMarkerLinkClick })))))));
};
//# sourceMappingURL=index.js.map