import React, { useContext, useState, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import { mapUtils } from "@local-logic/core/utils";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import errorTracker from "~/utils/errorTracker";
import { useMarkers } from "./hooks/useMarkers";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
import { radiusOptions } from "./constants";
const NeighborhoodMapContext = React.createContext({});
const useNeighborhoodMap = () => useContext(NeighborhoodMapContext);
const NeighborhoodMapProvider = ({ children, }) => {
    var _a, _b, _c, _d, _e;
    const { sdkState } = useStateManagerContext();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    const tracking = useTracking();
    const [activePoiCategory, setActivePoiCategory] = useState();
    const [radius, setRadius] = useState(radiusOptions[((_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.distanceUnit) || "metric"][0]);
    const radiusToMeters = useMemo(() => {
        var _a;
        // Default, km to m = km * 1000
        let multiplier = 1000;
        if (((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.distanceUnit) === "imperial") {
            // Imperial = mi to m = mi x the multiplier (converting MILES to METERS)
            multiplier = 1609.344;
        }
        return radius * multiplier;
    }, [radius]);
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
            eventAttributes: [
                {
                    label: "default_category",
                    data: activePoiCategory,
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
            eventAttributes: {
                ll_default_category: activePoiCategory,
            },
        });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo, geographies, } = useGeoLocationInfo({
        lat: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lat,
        lng: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.lng,
        geographyId: (_e = sdkState.options) === null || _e === void 0 ? void 0 : _e.geographyId,
        locale,
        include: "geometry",
    });
    const { data: markers, isLoading: isMarkersLoading } = useMarkers({
        lat: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates.lat,
        lng: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.coordinates.lng,
        category: activePoiCategory,
        radius: radiusToMeters,
    });
    const neighborhoodGeometry = useMemo(() => {
        var _a;
        if (isGeoLocationInfoLoading)
            return undefined;
        let selectedGeography;
        if ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.geographyId) {
            selectedGeography = Object.values(geographies || {}).find((geography) => {
                var _a, _b;
                return geography.level ===
                    Number((_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.geographyId) === null || _b === void 0 ? void 0 : _b.substring(1, 3));
            });
        }
        else {
            selectedGeography =
                Object.values(geographies || {}).sort((a, b) => a.level - b.level)[0] || undefined;
        }
        if (!selectedGeography)
            return undefined;
        return mapUtils.formatGeometry(selectedGeography.geometry);
    }, [geographies, isGeoLocationInfoLoading]);
    const handleRadiusChange = (newRadius) => {
        var _a, _b;
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SEARCH_RADIUS_CHANGED,
            eventAttributes: [
                {
                    label: "previous_radius",
                    data: radius,
                },
                {
                    label: "new_radius",
                    data: newRadius,
                },
                {
                    label: "distance_unit",
                    data: ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.distanceUnit) || "metric",
                },
            ],
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SEARCH_RADIUS_CHANGED,
            eventAttributes: {
                ll_previous_radius: radius,
                ll_new_radius: newRadius,
                ll_distance_unit: ((_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.distanceUnit) || "metric",
            },
        });
        errorTracker.addBreadCrumb("NeighborhoodMapProvider", "handleRadiusChange", {
            newRadius,
        });
        setRadius(newRadius);
    };
    const handleSelectPoiCategory = (category) => {
        errorTracker.addBreadCrumb("NeighborhoodMapProvider", "handleSelectPoiCategory", {
            category,
        });
        setActivePoiCategory(activePoiCategory === category ? undefined : category);
    };
    const isLoading = useMemo(() => isGeoLocationInfoLoading || isMarkersLoading, [isGeoLocationInfoLoading, isMarkersLoading]);
    return (React.createElement(NeighborhoodMapContext.Provider, { value: {
            isLoading,
            radius,
            onRadiusChange: handleRadiusChange,
            locationInfo,
            neighborhoodGeometry,
            activePoiCategory,
            onSelectPoiCategory: handleSelectPoiCategory,
            markers,
        } }, children));
};
export { useNeighborhoodMap, NeighborhoodMapProvider };
//# sourceMappingURL=context.js.map