import React, { useContext, useMemo, useState } from "react";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { useGeoLocationInfo } from "~/hooks/useGeoLocationInfo";
import { useSimilarNeighborhoods } from "~/features/clientLibrary/useSimilarNeighborhoods";
import { useResponsiveBreakpoints } from "~/hooks/useResponsiveBreakpoints";
import { useTracking } from "@local-logic/core/tracking";
import { TrackingPipelineEvents, AnalyticsEvents, } from "~/sdks/NeighborhoodMatch/types";
import { addAffordabilityComparisonToNeighborhood } from "./utils/affordability";
const MIN_PER_ROW = 4;
const MAX_LIMIT = 8;
const NeighborhoodMatchContext = React.createContext({});
const useNeighborhoodMatch = () => useContext(NeighborhoodMatchContext);
const NeighborhoodMatchProvider = ({ children, }) => {
    var _a, _b, _c, _d, _e, _f;
    const { sdkState } = useStateManagerContext();
    const locale = ((_a = sdkState.globalOptions) === null || _a === void 0 ? void 0 : _a.locale) || "en";
    const tracking = useTracking();
    const breakpoints = useResponsiveBreakpoints();
    const [limit, setLimit] = useState(MIN_PER_ROW);
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({ eventName: AnalyticsEvents.SDK_VIEWED });
    });
    const { isLoading: isGeoLocationInfoLoading, locationInfo } = useGeoLocationInfo({
        lat: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lat,
        lng: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.lng,
        geographyId: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.geographyId,
        externalId: (_e = sdkState.globalOptions) === null || _e === void 0 ? void 0 : _e.externalId,
        locale,
    });
    const { isLoading: isSimilarNeighborhoodsLoading, isFetched: isSimilarNeighborhoodsFetched, data: similarNeighborhoodsData, } = useSimilarNeighborhoods({
        geogID: locationInfo === null || locationInfo === void 0 ? void 0 : locationInfo.geogID,
        externalId: (_f = sdkState.globalOptions) === null || _f === void 0 ? void 0 : _f.externalId,
        limit: MAX_LIMIT,
    });
    const similarNeighborhoods = useMemo(() => {
        let neighborhoods = [];
        if (!similarNeighborhoodsData || !similarNeighborhoodsData.most_similar) {
            return neighborhoods;
        }
        if (similarNeighborhoodsData.most_similar.length < limit ||
            !(breakpoints === null || breakpoints === void 0 ? void 0 : breakpoints.lg)) {
            // Somehow we wouldn't have enough to return.
            // So just return what we have
            // We'll also return everything on mobile
            neighborhoods = [...similarNeighborhoodsData.most_similar];
        }
        else {
            neighborhoods = similarNeighborhoodsData.most_similar.slice(0, limit);
        }
        return neighborhoods.map((similarNeighborhood) => addAffordabilityComparisonToNeighborhood((similarNeighborhoodsData === null || similarNeighborhoodsData === void 0 ? void 0 : similarNeighborhoodsData.affordability_index) || undefined, similarNeighborhood));
    }, [similarNeighborhoodsData, limit, breakpoints]);
    const isLoading = useMemo(() => isGeoLocationInfoLoading || isSimilarNeighborhoodsLoading, [isGeoLocationInfoLoading, isSimilarNeighborhoodsLoading]);
    const viewMore = () => {
        if (limit === MAX_LIMIT) {
            return;
        }
        setLimit(limit + MIN_PER_ROW);
    };
    const viewLess = () => {
        if (limit < MAX_LIMIT) {
            return;
        }
        setLimit(limit - MIN_PER_ROW);
    };
    const contextValue = useMemo(() => {
        var _a, _b, _c;
        return ({
            limit,
            minimumLimit: MIN_PER_ROW,
            hasMore: ((similarNeighborhoodsData === null || similarNeighborhoodsData === void 0 ? void 0 : similarNeighborhoodsData.most_similar) || []).length > MIN_PER_ROW &&
                limit < MAX_LIMIT,
            viewMore,
            viewLess,
            isLoading,
            isFetched: isSimilarNeighborhoodsFetched,
            locationInfo,
            similarNeighborhoods,
            hideAffordabilityTags: (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.hideAffordabilityTags,
            hideAttribution: (_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.hideAttribution,
            hideThumbnails: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.hideThumbnails,
        });
    }, [
        limit,
        isLoading,
        isSimilarNeighborhoodsFetched,
        locationInfo,
        similarNeighborhoods,
    ]);
    return (React.createElement(NeighborhoodMatchContext.Provider, { value: contextValue }, children));
};
export { useNeighborhoodMatch, NeighborhoodMatchProvider };
//# sourceMappingURL=context.js.map